# COPR Ligenix's spec file for glpi-plugin-behaviors
#
# Copyright (c) 2021 Jean-Marc Liger 
#
# Forked from:
#
# remirepo spec file for glpi-behaviors
#
# Copyright (c) 2012-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname behaviors
%global glpi_min   9.5.4
%global glpi_max   9.6


Name:           glpi-plugin-%{pluginname}
Version:        2.6.1
Release:        1%{?dist}
Summary:        Plugin to add optional behaviors to GLPI
Summary(fr):    Extension ajoutant des comportements optionnels à GLPI

License:        AGPLv3+
URL:            https://github.com/yllen/%{pluginname}

Source0:        https://github.com/yllen/%{pluginname}/releases/download/v%{version}/glpi-%{pluginname}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  gettext

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif
Provides:       glpi-%{pluginname} = %{version}-%{release}
Obsoletes:      glpi-%{pluginname} <= 2.3.2


%description
This plugin allows you to add optional behaviors to GLPI.

%description -l fr
Cette extension permet d’ajouter des comportements optionnels à GLPI.


%prep
%setup -q -c

# remove unused files
rm %{pluginname}/%{pluginname}.xml

# move doc files
mkdir docs
mv %{pluginname}/README docs/

# create link to LICENSE for standard doc folder
ln -s %{_datadir}/glpi/plugins/%{pluginname}/LICENSE LICENSE


%build
# regenerate the locales
for po in %{pluginname}/locales/*.po
do
   msgfmt $po -o $(dirname $po)/$(basename $po .po).mo
done


%install
mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}

for i in %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}/locales/*
do
  lang=$(basename $i)
  echo "%lang(${lang:0:2}) %{_datadir}/glpi/plugins/%{pluginname}/locales/${lang}"
done | tee %{name}.lang


%files -f %{name}.lang
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc docs
%dir %{_datadir}/glpi/plugins/%{pluginname}
%dir %{_datadir}/glpi/plugins/%{pluginname}/locales
# LICENSE file required by installation process
%{_datadir}/glpi/plugins/%{pluginname}/LICENSE
%{_datadir}/glpi/plugins/%{pluginname}/%{pluginname}.png
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/inc
%{_datadir}/glpi/plugins/%{pluginname}/script


%changelog
* Mon Nov 27 2023 Jean-Marc Liger <ligenix@iscp.fr> - 2.6.1-1
- version 2.6.1

* Fri Jul 29 2022 Jean-Marc Liger <ligenix@iscp.fr> - 2.6.0-1
- version 2.6.0
- new github source
  https://github.com/yllen/behaviors/wiki

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.5.0-2
- update spec file's copyright, thanks again to Remy Collet!

* Mon Apr 12 2021 Jean-Marc Liger <ligenix@iscp.fr> - 2.5.0-1
- rename to glpi-plugin-behaviors
- version 2.5.0 for GLPI >= 9.5.4
  https://forge.glpi-project.org/versions/1324

* Thu Sep  3 2020 Remi Collet <remi@remirepo.net> - 2.3.2-1
- version 2.3.2 for GLPI 9.4
  https://forge.glpi-project.org/versions/1313

* Tue Aug 25 2020 Remi Collet <remi@remirepo.net> - 2.3.1-1
- version 2.3.1 for GLPI 9.4

* Thu Jul 23 2020 Remi Collet <remi@remirepo.net> - 2.3.0-1
- version 2.3.0 for GLPI 9.4
  https://forge.glpi-project.org/versions/1302

* Mon Sep 23 2019 Remi Collet <remi@remirepo.net> - 2.2.2-1
- version 2.2.2 for GLPI 9.4
  https://forge.glpi-project.org/versions/1299

* Thu Mar 28 2019 Remi Collet <remi@remirepo.net> - 2.2.1-1
- version 2.2.1 for GLPI 9.4
  https://forge.glpi-project.org/versions/1290

* Mon Feb 25 2019 Remi Collet <remi@remirepo.net> - 2.2.0-1
- version 2.2.0 for GLPI 9.4
  https://forge.glpi-project.org/versions/1287

* Wed Sep 12 2018 Remi Collet <remi@remirepo.net> - 2.1.1-1
- version 2.1.1 for GLPI 9.3
  https://forge.glpi-project.org/versions/1272

* Thu Sep  6 2018 Remi Collet <remi@remirepo.net> - 2.1.0-1
- version 2.1.0 for GLPI 9.3
  https://forge.glpi-project.org/versions/1270

* Fri Feb 23 2018 Remi Collet <remi@remirepo.net> - 2.0.2-1
- version 2.0.2 for GLPI 9.2
  https://forge.glpi-project.org/versions/1256

* Fri Jan 12 2018 Remi Collet <remi@remirepo.net> - 2.0.1-1
- version 2.0.1 for GLPI 9.2
  https://forge.glpi-project.org/versions/1252

* Wed Oct 18 2017 Remi Collet <remi@remirepo.net> - 2.0.0-1
- version 2.0.0 for GLPI 9.2
  https://forge.glpi-project.org/versions/1246

* Tue Oct  3 2017 Remi Collet <remi@remirepo.net> - 1.5.2-1
- version 1.5.2 for GLPI 9.1.5 and 9.2
  https://forge.glpi-project.org/versions/1240

* Tue Oct  3 2017 Remi Collet <remi@remirepo.net> - 1.5.1-1
- version 1.5.1 for GLPI 9.1.5 and 9.2
  https://forge.glpi-project.org/versions/1239

* Wed Aug 16 2017 Remi Collet <remi@remirepo.net> - 1.5.0-1
- version 1.5.0 for GLPI 9.1.5
  https://forge.glpi-project.org/versions/1230

* Tue Jul  4 2017 Remi Collet <remi@remirepo.net> - 1.4.0-1
- version 1.4.0 for GLPI 9.1
  https://forge.glpi-project.org/versions/1230

* Fri Mar 03 2017 Johan Cwiklinski <jcwiklinski AT teclib DOT com> - 1.3-1
- version 1.3 got GLPI 9.1
  https://forge.glpi-project.org/versions/1224

* Tue Nov  8 2016 Remi Collet <remi@fedoraproject.org> - 1.2-1
- version 1.2 for GLPI 9.1
  https://forge.glpi-project.org/versions/1214

* Tue Nov  8 2016 Remi Collet <remi@fedoraproject.org> - 1.1-1
- version 1.1
  https://forge.glpi-project.org/versions/1209

* Thu Feb 25 2016 Remi Collet <remi@fedoraproject.org> - 1.0-1
- version 1.0
  https://forge.glpi-project.org/versions/1182

* Tue Oct  6 2015 Remi Collet <remi@fedoraproject.org> - 0.90-1
- version 0.90
  https://forge.glpi-project.org/versions/1101

* Wed Dec 17 2014 Remi Collet <remi@fedoraproject.org> - 0.85-1
- version 0.85
  https://forge.indepnet.net/versions/922

* Mon Nov 17 2014 Remi Collet <remi@fedoraproject.org> - 0.84.3-1
- version 0.84.3
  https://forge.indepnet.net/versions/1100

* Mon Sep  8 2014 Remi Collet <remi@fedoraproject.org> - 0.84.2-1
- version 0.84.2 for GLPI 0.84
  https://forge.indepnet.net/versions/1021

* Mon Sep 30 2013 Remi Collet <remi@fedoraproject.org> - 0.84.1-1
- version 0.84.1 for GLPI 0.84

* Fri Jan 11 2013 Remi Collet <Fedora@FamilleCollet.com> - 0.83.4-1
- version 0.83.4 for GLPI >= 0.83.4
  https://forge.indepnet.net/projects/behaviors/versions/787

* Thu Jul 12 2012 Remi Collet <Fedora@FamilleCollet.com> - 0.83.3-1
- version 0.83.3 for GLPI 0.83.3
  https://forge.indepnet.net/projects/behaviors/versions/752

* Thu Apr 19 2012 Remi Collet <Fedora@FamilleCollet.com> - 0.83.0-1
- Initial RPM

